@@ -20,6 +20,7 @@
 #ifdef HAVE_FREETYPE
 #include "batchrenamer.h"
 #include "fontplugin.h"
+#include "tokenhelpdialog.h"
 
 #include <ft2build.h>
 #include FT_FREETYPE_H
@@ -34,9 +35,9 @@ FontPlugin::FontPlugin( PluginLoader* loader )
     this->addSupportedToken("fontpostscript");
     this->addSupportedToken("fontfamily");
     this->addSupportedToken("fontstyle");
-    m_help.append( "[fontPostscript]" + Plugin::S_TOKEN_SEPARATOR + i18n("Insert the Postscript name for Type1 and TrueType fonts.") );
-    m_help.append( "[fontFamily]" + Plugin::S_TOKEN_SEPARATOR + i18n("Insert the (usually English) name of the font family.") );
-    m_help.append( "[fontStyle]" + Plugin::S_TOKEN_SEPARATOR + i18n("Insert the (usually English) name of the font style.") );
+    m_help.append( "[fontPostscript]" + TokenHelpDialog::getTokenSeparator() + i18n("Insert the Postscript name for Type1 and TrueType fonts.") );
+    m_help.append( "[fontFamily]" + TokenHelpDialog::getTokenSeparator() + i18n("Insert the (usually English) name of the font family.") );
+    m_help.append( "[fontStyle]" + TokenHelpDialog::getTokenSeparator() + i18n("Insert the (usually English) name of the font style.") );
 
     m_name = i18n("Font (FreeType2) Plugin");
     m_comment = i18n("<qt>This plugin supports reading tags from "
