@@ -48,24 +48,24 @@ SystemPlugin::SystemPlugin(  PluginLoader* loader )
     this->addSupportedToken("accessdate;.*");
     this->addSupportedToken("filesize");
  
-    m_help.append( "[date];;" + i18n("Insert the current date") );
-    m_help.append( "[date;yyyy-MM-dd];;" + i18n("Insert the current date using the formatting string yyyy-MM-dd") );
-    m_help.append( "[year];;" + i18n("Insert the current year") );
-    m_help.append( "[month];;" + i18n("Insert the current month as number") );
-    m_help.append( "[day];;" + i18n("Insert the current day as number") );
-    m_help.append( "[time];;" + i18n("Insert the current time") );
-    m_help.append( "[hour];;" + i18n("Insert the current hour as number") );
-    m_help.append( "[minute];;" + i18n("Insert the current minute as number") );
-    m_help.append( "[second];;" + i18n("Insert the current second as number") );
-    m_help.append( "[user];;" + i18n("Owner of the file") );
-    m_help.append( "[group];;" + i18n("Owning group of the file") );
-    m_help.append( "[creationdate];;" + i18n("Insert the files creation date"));
-    m_help.append( "[creationdate;yyyy-MM-dd];;" + i18n("Insert the formatted file creation date") );
-    m_help.append( "[modificationdate];;" + i18n("Insert the files modification date"));
-    m_help.append( "[modificationdate;yyyy-MM-dd];;" + i18n("Insert the formatted modification date") );
-    m_help.append( "[accessdate];;" + i18n("Insert the date of the last file access") );
-    m_help.append( "[accessdate;yyyy-MM-dd];;" + i18n("Insert the formatted date of the last file access") );
-    m_help.append( "[filesize];;" + i18n("Insert the file size in bytes") );
+    m_help.append( Plugin::createHelpEntry("date", i18n("Insert the current date")) );
+    m_help.append( Plugin::createHelpEntry("date;yyyy-MM-dd", i18n("Insert the current date using the formatting string yyyy-MM-dd")) );
+    m_help.append( Plugin::createHelpEntry("year", i18n("Insert the current year")) );
+    m_help.append( Plugin::createHelpEntry("month", i18n("Insert the current month as number")) );
+    m_help.append( Plugin::createHelpEntry("day", i18n("Insert the current day as number")) );
+    m_help.append( Plugin::createHelpEntry("time", i18n("Insert the current time")) );
+    m_help.append( Plugin::createHelpEntry("hour", i18n("Insert the current hour as number")) );
+    m_help.append( Plugin::createHelpEntry("minute", i18n("Insert the current minute as number")) );
+    m_help.append( Plugin::createHelpEntry("second", i18n("Insert the current second as number")) );
+    m_help.append( Plugin::createHelpEntry("user", i18n("Owner of the file")) );
+    m_help.append( Plugin::createHelpEntry("group", i18n("Owning group of the file")) );
+    m_help.append( Plugin::createHelpEntry("creationdate", i18n("Insert the files creation date")));
+    m_help.append( Plugin::createHelpEntry("creationdate;yyyy-MM-dd", i18n("Insert the formatted file creation date")) );
+    m_help.append( Plugin::createHelpEntry("modificationdate", i18n("Insert the files modification date")) );
+    m_help.append( Plugin::createHelpEntry("modificationdate;yyyy-MM-dd", i18n("Insert the formatted modification date")) );
+    m_help.append( Plugin::createHelpEntry("accessdate", i18n("Insert the date of the last file access")) );
+    m_help.append( Plugin::createHelpEntry("accessdate;yyyy-MM-dd", i18n("Insert the formatted date of the last file access")) );
+    m_help.append( Plugin::createHelpEntry("filesize", i18n("Insert the file size in bytes")) );
 
     m_name = i18n("Date and system functions");
     m_icon = "system-run";   
